# coding: utf-8

# flake8: noqa
"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from printnanny_api_client.models.alert import Alert
from printnanny_api_client.models.alert_bulk_response import AlertBulkResponse
from printnanny_api_client.models.alert_event_type_enum import AlertEventTypeEnum
from printnanny_api_client.models.alert_request import AlertRequest
from printnanny_api_client.models.alpha_event_source import AlphaEventSource
from printnanny_api_client.models.artifact_types_enum import ArtifactTypesEnum
from printnanny_api_client.models.callback_token_auth_request import CallbackTokenAuthRequest
from printnanny_api_client.models.callback_token_verification import CallbackTokenVerification
from printnanny_api_client.models.callback_token_verification_request import CallbackTokenVerificationRequest
from printnanny_api_client.models.camera import Camera
from printnanny_api_client.models.camera_request import CameraRequest
from printnanny_api_client.models.camera_type import CameraType
from printnanny_api_client.models.cloudiot_device import CloudiotDevice
from printnanny_api_client.models.cloudiot_device_request import CloudiotDeviceRequest
from printnanny_api_client.models.command_enum import CommandEnum
from printnanny_api_client.models.detail_response import DetailResponse
from printnanny_api_client.models.device import Device
from printnanny_api_client.models.device_calibration import DeviceCalibration
from printnanny_api_client.models.device_calibration_request import DeviceCalibrationRequest
from printnanny_api_client.models.device_request import DeviceRequest
from printnanny_api_client.models.email_auth_request import EmailAuthRequest
from printnanny_api_client.models.error_detail import ErrorDetail
from printnanny_api_client.models.experiment import Experiment
from printnanny_api_client.models.experiment_device_config import ExperimentDeviceConfig
from printnanny_api_client.models.gcode_file import GcodeFile
from printnanny_api_client.models.license import License
from printnanny_api_client.models.license_request import LicenseRequest
from printnanny_api_client.models.mobile_auth_request import MobileAuthRequest
from printnanny_api_client.models.model_artifact import ModelArtifact
from printnanny_api_client.models.octo_generic_event import OctoGenericEvent
from printnanny_api_client.models.octo_job_event import OctoJobEvent
from printnanny_api_client.models.octo_print_device import OctoPrintDevice
from printnanny_api_client.models.octo_print_device_key import OctoPrintDeviceKey
from printnanny_api_client.models.octo_print_device_request import OctoPrintDeviceRequest
from printnanny_api_client.models.octo_print_event import OctoPrintEvent
from printnanny_api_client.models.octo_print_event_request import OctoPrintEventRequest
from printnanny_api_client.models.octo_print_nanny_event import OctoPrintNannyEvent
from printnanny_api_client.models.octo_printer_event import OctoPrinterEvent
from printnanny_api_client.models.octo_telemetry_event import OctoTelemetryEvent
from printnanny_api_client.models.octoprint_environment import OctoprintEnvironment
from printnanny_api_client.models.octoprint_environment_request import OctoprintEnvironmentRequest
from printnanny_api_client.models.octoprint_file import OctoprintFile
from printnanny_api_client.models.octoprint_file_request import OctoprintFileRequest
from printnanny_api_client.models.octoprint_hardware import OctoprintHardware
from printnanny_api_client.models.octoprint_hardware_request import OctoprintHardwareRequest
from printnanny_api_client.models.octoprint_job import OctoprintJob
from printnanny_api_client.models.octoprint_job_request import OctoprintJobRequest
from printnanny_api_client.models.octoprint_pi_support import OctoprintPiSupport
from printnanny_api_client.models.octoprint_pi_support_request import OctoprintPiSupportRequest
from printnanny_api_client.models.octoprint_platform import OctoprintPlatform
from printnanny_api_client.models.octoprint_platform_request import OctoprintPlatformRequest
from printnanny_api_client.models.octoprint_printer_data import OctoprintPrinterData
from printnanny_api_client.models.octoprint_printer_data_request import OctoprintPrinterDataRequest
from printnanny_api_client.models.octoprint_printer_flags import OctoprintPrinterFlags
from printnanny_api_client.models.octoprint_printer_flags_request import OctoprintPrinterFlagsRequest
from printnanny_api_client.models.octoprint_printer_state import OctoprintPrinterState
from printnanny_api_client.models.octoprint_printer_state_request import OctoprintPrinterStateRequest
from printnanny_api_client.models.octoprint_progress import OctoprintProgress
from printnanny_api_client.models.octoprint_progress_request import OctoprintProgressRequest
from printnanny_api_client.models.octoprint_python import OctoprintPython
from printnanny_api_client.models.octoprint_python_request import OctoprintPythonRequest
from printnanny_api_client.models.paginated_alert_list import PaginatedAlertList
from printnanny_api_client.models.paginated_camera_list import PaginatedCameraList
from printnanny_api_client.models.paginated_cloudiot_device_list import PaginatedCloudiotDeviceList
from printnanny_api_client.models.paginated_device_calibration_list import PaginatedDeviceCalibrationList
from printnanny_api_client.models.paginated_device_list import PaginatedDeviceList
from printnanny_api_client.models.paginated_experiment_device_config_list import PaginatedExperimentDeviceConfigList
from printnanny_api_client.models.paginated_experiment_list import PaginatedExperimentList
from printnanny_api_client.models.paginated_gcode_file_list import PaginatedGcodeFileList
from printnanny_api_client.models.paginated_license_list import PaginatedLicenseList
from printnanny_api_client.models.paginated_model_artifact_list import PaginatedModelArtifactList
from printnanny_api_client.models.paginated_octo_print_device_list import PaginatedOctoPrintDeviceList
from printnanny_api_client.models.paginated_octo_print_event_list import PaginatedOctoPrintEventList
from printnanny_api_client.models.paginated_print_job_event_list import PaginatedPrintJobEventList
from printnanny_api_client.models.paginated_print_nanny_plugin_event_list import PaginatedPrintNannyPluginEventList
from printnanny_api_client.models.paginated_print_session_list import PaginatedPrintSessionList
from printnanny_api_client.models.paginated_printer_controller_list import PaginatedPrinterControllerList
from printnanny_api_client.models.paginated_printer_profile_list import PaginatedPrinterProfileList
from printnanny_api_client.models.paginated_remote_command_event_list import PaginatedRemoteCommandEventList
from printnanny_api_client.models.paginated_remote_control_command_list import PaginatedRemoteControlCommandList
from printnanny_api_client.models.paginated_system_info_list import PaginatedSystemInfoList
from printnanny_api_client.models.paginated_task_list import PaginatedTaskList
from printnanny_api_client.models.paginated_task_status_list import PaginatedTaskStatusList
from printnanny_api_client.models.paginated_telemetry_event_polymorphic_list import PaginatedTelemetryEventPolymorphicList
from printnanny_api_client.models.partner3_d_geeks_alert import Partner3DGeeksAlert
from printnanny_api_client.models.partner3_d_geeks_metadata import Partner3DGeeksMetadata
from printnanny_api_client.models.patched_alert_bulk_request_request import PatchedAlertBulkRequestRequest
from printnanny_api_client.models.patched_alert_request import PatchedAlertRequest
from printnanny_api_client.models.patched_camera_request import PatchedCameraRequest
from printnanny_api_client.models.patched_cloudiot_device_request import PatchedCloudiotDeviceRequest
from printnanny_api_client.models.patched_device_calibration_request import PatchedDeviceCalibrationRequest
from printnanny_api_client.models.patched_device_request import PatchedDeviceRequest
from printnanny_api_client.models.patched_octo_print_device_request import PatchedOctoPrintDeviceRequest
from printnanny_api_client.models.patched_print_session_request import PatchedPrintSessionRequest
from printnanny_api_client.models.patched_printer_controller_request import PatchedPrinterControllerRequest
from printnanny_api_client.models.patched_printer_profile_request import PatchedPrinterProfileRequest
from printnanny_api_client.models.patched_remote_control_command_request import PatchedRemoteControlCommandRequest
from printnanny_api_client.models.patched_system_info_request import PatchedSystemInfoRequest
from printnanny_api_client.models.patched_user_request import PatchedUserRequest
from printnanny_api_client.models.print_job_event import PrintJobEvent
from printnanny_api_client.models.print_job_event_request import PrintJobEventRequest
from printnanny_api_client.models.print_nanny_api_config import PrintNannyApiConfig
from printnanny_api_client.models.print_nanny_plugin_event import PrintNannyPluginEvent
from printnanny_api_client.models.print_nanny_plugin_event_request import PrintNannyPluginEventRequest
from printnanny_api_client.models.print_session import PrintSession
from printnanny_api_client.models.print_session_request import PrintSessionRequest
from printnanny_api_client.models.printer_controller import PrinterController
from printnanny_api_client.models.printer_controller_request import PrinterControllerRequest
from printnanny_api_client.models.printer_event import PrinterEvent
from printnanny_api_client.models.printer_event_request import PrinterEventRequest
from printnanny_api_client.models.printer_profile import PrinterProfile
from printnanny_api_client.models.printer_profile_request import PrinterProfileRequest
from printnanny_api_client.models.printnanny_env_enum import PrintnannyEnvEnum
from printnanny_api_client.models.release_channel_enum import ReleaseChannelEnum
from printnanny_api_client.models.remote_command_event import RemoteCommandEvent
from printnanny_api_client.models.remote_command_event_event_type_enum import RemoteCommandEventEventTypeEnum
from printnanny_api_client.models.remote_command_event_request import RemoteCommandEventRequest
from printnanny_api_client.models.remote_control_command import RemoteControlCommand
from printnanny_api_client.models.remote_control_command_request import RemoteControlCommandRequest
from printnanny_api_client.models.software_enum import SoftwareEnum
from printnanny_api_client.models.system_info import SystemInfo
from printnanny_api_client.models.system_info_request import SystemInfoRequest
from printnanny_api_client.models.task import Task
from printnanny_api_client.models.task_request import TaskRequest
from printnanny_api_client.models.task_status import TaskStatus
from printnanny_api_client.models.task_status_request import TaskStatusRequest
from printnanny_api_client.models.task_status_type import TaskStatusType
from printnanny_api_client.models.task_type import TaskType
from printnanny_api_client.models.telemetry_event import TelemetryEvent
from printnanny_api_client.models.telemetry_event_polymorphic import TelemetryEventPolymorphic
from printnanny_api_client.models.telemetry_event_polymorphic_request import TelemetryEventPolymorphicRequest
from printnanny_api_client.models.telemetry_event_request import TelemetryEventRequest
from printnanny_api_client.models.token_response import TokenResponse
from printnanny_api_client.models.user import User
from printnanny_api_client.models.user_request import UserRequest



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class DeviceCalibration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'octoprint_device': 'int',
        'fps': 'float',
        'xy': 'dict(str, object)',
        'height': 'int',
        'width': 'int',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'octoprint_device': 'octoprint_device',
        'fps': 'fps',
        'xy': 'xy',
        'height': 'height',
        'width': 'width',
        'url': 'url'
    }

    def __init__(self, id=None, created_dt=None, updated_dt=None, octoprint_device=None, fps=None, xy=None, height=None, width=None, url=None, local_vars_configuration=None):  # noqa: E501
        """DeviceCalibration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_dt = None
        self._updated_dt = None
        self._octoprint_device = None
        self._fps = None
        self._xy = None
        self._height = None
        self._width = None
        self._url = None
        self.discriminator = None

        self.id = id
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.octoprint_device = octoprint_device
        if fps is not None:
            self.fps = fps
        self.xy = xy
        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        self.url = url

    @property
    def id(self):
        """Gets the id of this DeviceCalibration.  # noqa: E501


        :return: The id of this DeviceCalibration.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceCalibration.


        :param id: The id of this DeviceCalibration.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_dt(self):
        """Gets the created_dt of this DeviceCalibration.  # noqa: E501


        :return: The created_dt of this DeviceCalibration.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this DeviceCalibration.


        :param created_dt: The created_dt of this DeviceCalibration.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this DeviceCalibration.  # noqa: E501


        :return: The updated_dt of this DeviceCalibration.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this DeviceCalibration.


        :param updated_dt: The updated_dt of this DeviceCalibration.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def octoprint_device(self):
        """Gets the octoprint_device of this DeviceCalibration.  # noqa: E501


        :return: The octoprint_device of this DeviceCalibration.  # noqa: E501
        :rtype: int
        """
        return self._octoprint_device

    @octoprint_device.setter
    def octoprint_device(self, octoprint_device):
        """Sets the octoprint_device of this DeviceCalibration.


        :param octoprint_device: The octoprint_device of this DeviceCalibration.  # noqa: E501
        :type octoprint_device: int
        """
        if self.local_vars_configuration.client_side_validation and octoprint_device is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_device`, must not be `None`")  # noqa: E501

        self._octoprint_device = octoprint_device

    @property
    def fps(self):
        """Gets the fps of this DeviceCalibration.  # noqa: E501


        :return: The fps of this DeviceCalibration.  # noqa: E501
        :rtype: float
        """
        return self._fps

    @fps.setter
    def fps(self, fps):
        """Sets the fps of this DeviceCalibration.


        :param fps: The fps of this DeviceCalibration.  # noqa: E501
        :type fps: float
        """

        self._fps = fps

    @property
    def xy(self):
        """Gets the xy of this DeviceCalibration.  # noqa: E501


        :return: The xy of this DeviceCalibration.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._xy

    @xy.setter
    def xy(self, xy):
        """Sets the xy of this DeviceCalibration.


        :param xy: The xy of this DeviceCalibration.  # noqa: E501
        :type xy: dict(str, object)
        """

        self._xy = xy

    @property
    def height(self):
        """Gets the height of this DeviceCalibration.  # noqa: E501


        :return: The height of this DeviceCalibration.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this DeviceCalibration.


        :param height: The height of this DeviceCalibration.  # noqa: E501
        :type height: int
        """
        if (self.local_vars_configuration.client_side_validation and
                height is not None and height > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `height`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                height is not None and height < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `height`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._height = height

    @property
    def width(self):
        """Gets the width of this DeviceCalibration.  # noqa: E501


        :return: The width of this DeviceCalibration.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DeviceCalibration.


        :param width: The width of this DeviceCalibration.  # noqa: E501
        :type width: int
        """
        if (self.local_vars_configuration.client_side_validation and
                width is not None and width > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `width`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                width is not None and width < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `width`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._width = width

    @property
    def url(self):
        """Gets the url of this DeviceCalibration.  # noqa: E501


        :return: The url of this DeviceCalibration.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this DeviceCalibration.


        :param url: The url of this DeviceCalibration.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceCalibration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceCalibration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PrintSession(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'created_dt': 'datetime',
        'updated_dt': 'datetime',
        'octoprint_device': 'int',
        'active': 'bool',
        'session': 'str',
        'filepos': 'int',
        'print_progress': 'int',
        'time_elapsed': 'int',
        'time_remaining': 'int',
        'user': 'int',
        'printer_profile': 'int',
        'gcode_file': 'int',
        'gcode_filename': 'str',
        'octoprint_job': 'dict(str, object)',
        'print_job_status': 'OctoJobEvent',
        'url': 'str',
        'datesegment': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_dt': 'created_dt',
        'updated_dt': 'updated_dt',
        'octoprint_device': 'octoprint_device',
        'active': 'active',
        'session': 'session',
        'filepos': 'filepos',
        'print_progress': 'print_progress',
        'time_elapsed': 'time_elapsed',
        'time_remaining': 'time_remaining',
        'user': 'user',
        'printer_profile': 'printer_profile',
        'gcode_file': 'gcode_file',
        'gcode_filename': 'gcode_filename',
        'octoprint_job': 'octoprint_job',
        'print_job_status': 'print_job_status',
        'url': 'url',
        'datesegment': 'datesegment'
    }

    def __init__(self, id=None, created_dt=None, updated_dt=None, octoprint_device=None, active=None, session=None, filepos=None, print_progress=None, time_elapsed=None, time_remaining=None, user=None, printer_profile=None, gcode_file=None, gcode_filename=None, octoprint_job=None, print_job_status=None, url=None, datesegment=None, local_vars_configuration=None):  # noqa: E501
        """PrintSession - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_dt = None
        self._updated_dt = None
        self._octoprint_device = None
        self._active = None
        self._session = None
        self._filepos = None
        self._print_progress = None
        self._time_elapsed = None
        self._time_remaining = None
        self._user = None
        self._printer_profile = None
        self._gcode_file = None
        self._gcode_filename = None
        self._octoprint_job = None
        self._print_job_status = None
        self._url = None
        self._datesegment = None
        self.discriminator = None

        self.id = id
        self.created_dt = created_dt
        self.updated_dt = updated_dt
        self.octoprint_device = octoprint_device
        if active is not None:
            self.active = active
        self.session = session
        self.filepos = filepos
        self.print_progress = print_progress
        self.time_elapsed = time_elapsed
        self.time_remaining = time_remaining
        self.user = user
        self.printer_profile = printer_profile
        self.gcode_file = gcode_file
        self.gcode_filename = gcode_filename
        self.octoprint_job = octoprint_job
        self.print_job_status = print_job_status
        self.url = url
        self.datesegment = datesegment

    @property
    def id(self):
        """Gets the id of this PrintSession.  # noqa: E501


        :return: The id of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PrintSession.


        :param id: The id of this PrintSession.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_dt(self):
        """Gets the created_dt of this PrintSession.  # noqa: E501


        :return: The created_dt of this PrintSession.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this PrintSession.


        :param created_dt: The created_dt of this PrintSession.  # noqa: E501
        :type created_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `created_dt`, must not be `None`")  # noqa: E501

        self._created_dt = created_dt

    @property
    def updated_dt(self):
        """Gets the updated_dt of this PrintSession.  # noqa: E501


        :return: The updated_dt of this PrintSession.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this PrintSession.


        :param updated_dt: The updated_dt of this PrintSession.  # noqa: E501
        :type updated_dt: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_dt is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_dt`, must not be `None`")  # noqa: E501

        self._updated_dt = updated_dt

    @property
    def octoprint_device(self):
        """Gets the octoprint_device of this PrintSession.  # noqa: E501


        :return: The octoprint_device of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._octoprint_device

    @octoprint_device.setter
    def octoprint_device(self, octoprint_device):
        """Sets the octoprint_device of this PrintSession.


        :param octoprint_device: The octoprint_device of this PrintSession.  # noqa: E501
        :type octoprint_device: int
        """
        if self.local_vars_configuration.client_side_validation and octoprint_device is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_device`, must not be `None`")  # noqa: E501

        self._octoprint_device = octoprint_device

    @property
    def active(self):
        """Gets the active of this PrintSession.  # noqa: E501


        :return: The active of this PrintSession.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this PrintSession.


        :param active: The active of this PrintSession.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def session(self):
        """Gets the session of this PrintSession.  # noqa: E501


        :return: The session of this PrintSession.  # noqa: E501
        :rtype: str
        """
        return self._session

    @session.setter
    def session(self, session):
        """Sets the session of this PrintSession.


        :param session: The session of this PrintSession.  # noqa: E501
        :type session: str
        """
        if self.local_vars_configuration.client_side_validation and session is None:  # noqa: E501
            raise ValueError("Invalid value for `session`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                session is not None and len(session) > 255):
            raise ValueError("Invalid value for `session`, length must be less than or equal to `255`")  # noqa: E501

        self._session = session

    @property
    def filepos(self):
        """Gets the filepos of this PrintSession.  # noqa: E501


        :return: The filepos of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._filepos

    @filepos.setter
    def filepos(self, filepos):
        """Sets the filepos of this PrintSession.


        :param filepos: The filepos of this PrintSession.  # noqa: E501
        :type filepos: int
        """
        if (self.local_vars_configuration.client_side_validation and
                filepos is not None and filepos > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `filepos`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                filepos is not None and filepos < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `filepos`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._filepos = filepos

    @property
    def print_progress(self):
        """Gets the print_progress of this PrintSession.  # noqa: E501


        :return: The print_progress of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._print_progress

    @print_progress.setter
    def print_progress(self, print_progress):
        """Sets the print_progress of this PrintSession.


        :param print_progress: The print_progress of this PrintSession.  # noqa: E501
        :type print_progress: int
        """
        if (self.local_vars_configuration.client_side_validation and
                print_progress is not None and print_progress > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `print_progress`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_progress is not None and print_progress < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `print_progress`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._print_progress = print_progress

    @property
    def time_elapsed(self):
        """Gets the time_elapsed of this PrintSession.  # noqa: E501


        :return: The time_elapsed of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._time_elapsed

    @time_elapsed.setter
    def time_elapsed(self, time_elapsed):
        """Sets the time_elapsed of this PrintSession.


        :param time_elapsed: The time_elapsed of this PrintSession.  # noqa: E501
        :type time_elapsed: int
        """
        if (self.local_vars_configuration.client_side_validation and
                time_elapsed is not None and time_elapsed > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `time_elapsed`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                time_elapsed is not None and time_elapsed < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `time_elapsed`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._time_elapsed = time_elapsed

    @property
    def time_remaining(self):
        """Gets the time_remaining of this PrintSession.  # noqa: E501


        :return: The time_remaining of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._time_remaining

    @time_remaining.setter
    def time_remaining(self, time_remaining):
        """Sets the time_remaining of this PrintSession.


        :param time_remaining: The time_remaining of this PrintSession.  # noqa: E501
        :type time_remaining: int
        """
        if (self.local_vars_configuration.client_side_validation and
                time_remaining is not None and time_remaining > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `time_remaining`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                time_remaining is not None and time_remaining < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `time_remaining`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._time_remaining = time_remaining

    @property
    def user(self):
        """Gets the user of this PrintSession.  # noqa: E501


        :return: The user of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this PrintSession.


        :param user: The user of this PrintSession.  # noqa: E501
        :type user: int
        """
        if self.local_vars_configuration.client_side_validation and user is None:  # noqa: E501
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def printer_profile(self):
        """Gets the printer_profile of this PrintSession.  # noqa: E501


        :return: The printer_profile of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._printer_profile

    @printer_profile.setter
    def printer_profile(self, printer_profile):
        """Sets the printer_profile of this PrintSession.


        :param printer_profile: The printer_profile of this PrintSession.  # noqa: E501
        :type printer_profile: int
        """

        self._printer_profile = printer_profile

    @property
    def gcode_file(self):
        """Gets the gcode_file of this PrintSession.  # noqa: E501


        :return: The gcode_file of this PrintSession.  # noqa: E501
        :rtype: int
        """
        return self._gcode_file

    @gcode_file.setter
    def gcode_file(self, gcode_file):
        """Sets the gcode_file of this PrintSession.


        :param gcode_file: The gcode_file of this PrintSession.  # noqa: E501
        :type gcode_file: int
        """

        self._gcode_file = gcode_file

    @property
    def gcode_filename(self):
        """Gets the gcode_filename of this PrintSession.  # noqa: E501


        :return: The gcode_filename of this PrintSession.  # noqa: E501
        :rtype: str
        """
        return self._gcode_filename

    @gcode_filename.setter
    def gcode_filename(self, gcode_filename):
        """Sets the gcode_filename of this PrintSession.


        :param gcode_filename: The gcode_filename of this PrintSession.  # noqa: E501
        :type gcode_filename: str
        """
        if (self.local_vars_configuration.client_side_validation and
                gcode_filename is not None and len(gcode_filename) > 255):
            raise ValueError("Invalid value for `gcode_filename`, length must be less than or equal to `255`")  # noqa: E501

        self._gcode_filename = gcode_filename

    @property
    def octoprint_job(self):
        """Gets the octoprint_job of this PrintSession.  # noqa: E501


        :return: The octoprint_job of this PrintSession.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._octoprint_job

    @octoprint_job.setter
    def octoprint_job(self, octoprint_job):
        """Sets the octoprint_job of this PrintSession.


        :param octoprint_job: The octoprint_job of this PrintSession.  # noqa: E501
        :type octoprint_job: dict(str, object)
        """

        self._octoprint_job = octoprint_job

    @property
    def print_job_status(self):
        """Gets the print_job_status of this PrintSession.  # noqa: E501


        :return: The print_job_status of this PrintSession.  # noqa: E501
        :rtype: OctoJobEvent
        """
        return self._print_job_status

    @print_job_status.setter
    def print_job_status(self, print_job_status):
        """Sets the print_job_status of this PrintSession.


        :param print_job_status: The print_job_status of this PrintSession.  # noqa: E501
        :type print_job_status: OctoJobEvent
        """

        self._print_job_status = print_job_status

    @property
    def url(self):
        """Gets the url of this PrintSession.  # noqa: E501


        :return: The url of this PrintSession.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PrintSession.


        :param url: The url of this PrintSession.  # noqa: E501
        :type url: str
        """
        if self.local_vars_configuration.client_side_validation and url is None:  # noqa: E501
            raise ValueError("Invalid value for `url`, must not be `None`")  # noqa: E501

        self._url = url

    @property
    def datesegment(self):
        """Gets the datesegment of this PrintSession.  # noqa: E501


        :return: The datesegment of this PrintSession.  # noqa: E501
        :rtype: str
        """
        return self._datesegment

    @datesegment.setter
    def datesegment(self, datesegment):
        """Sets the datesegment of this PrintSession.


        :param datesegment: The datesegment of this PrintSession.  # noqa: E501
        :type datesegment: str
        """
        if self.local_vars_configuration.client_side_validation and datesegment is None:  # noqa: E501
            raise ValueError("Invalid value for `datesegment`, must not be `None`")  # noqa: E501

        self._datesegment = datesegment

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintSession):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintSession):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.paginated_octo_print_device_list import PaginatedOctoPrintDeviceList  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPaginatedOctoPrintDeviceList(unittest.TestCase):
    """PaginatedOctoPrintDeviceList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedOctoPrintDeviceList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.paginated_octo_print_device_list.PaginatedOctoPrintDeviceList()  # noqa: E501
        if include_optional :
            return PaginatedOctoPrintDeviceList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    printnanny_api_client.models.octo_print_device.OctoPrintDevice(
                        id = 56, 
                        created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        user = 56, 
                        public_key = '', 
                        fingerprint = '', 
                        cloudiot_device = {
                            'key' : null
                            }, 
                        cloudiot_device_name = '', 
                        cloudiot_device_path = '', 
                        cloudiot_device_num_id = 56, 
                        model = '', 
                        platform = '', 
                        cpu_flags = [
                            ''
                            ], 
                        hardware = '', 
                        revision = '', 
                        serial = '', 
                        cores = -2147483648, 
                        ram = -2147483648, 
                        python_version = '', 
                        pip_version = '', 
                        virtualenv = '', 
                        octoprint_version = '', 
                        plugin_version = '', 
                        print_nanny_client_version = '', 
                        print_nanny_beta_client_version = '', 
                        cloudiot_device_configs = '', 
                        manage_url = '', 
                        monitoring_active = True, 
                        active_session = printnanny_api_client.models.print_session.PrintSession(
                            id = 56, 
                            created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            octoprint_device = 56, 
                            active = True, 
                            session = '', 
                            filepos = -2147483648, 
                            print_progress = -2147483648, 
                            time_elapsed = -2147483648, 
                            time_remaining = -2147483648, 
                            user = 56, 
                            printer_profile = 56, 
                            gcode_file = 56, 
                            gcode_filename = '', 
                            octoprint_job = {
                                'key' : null
                                }, 
                            print_job_status = null, 
                            url = '', 
                            datesegment = '', ), )
                    ]
            )
        else :
            return PaginatedOctoPrintDeviceList(
        )

    def testPaginatedOctoPrintDeviceList(self):
        """Test PaginatedOctoPrintDeviceList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class CameraRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active': 'bool',
        'device': 'int',
        'name': 'str',
        'camera_type': 'CameraType'
    }

    attribute_map = {
        'active': 'active',
        'device': 'device',
        'name': 'name',
        'camera_type': 'camera_type'
    }

    def __init__(self, active=None, device=None, name='Raspberry Pi Cam', camera_type=None, local_vars_configuration=None):  # noqa: E501
        """CameraRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._active = None
        self._device = None
        self._name = None
        self._camera_type = None
        self.discriminator = None

        if active is not None:
            self.active = active
        self.device = device
        if name is not None:
            self.name = name
        self.camera_type = camera_type

    @property
    def active(self):
        """Gets the active of this CameraRequest.  # noqa: E501


        :return: The active of this CameraRequest.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this CameraRequest.


        :param active: The active of this CameraRequest.  # noqa: E501
        :type active: bool
        """

        self._active = active

    @property
    def device(self):
        """Gets the device of this CameraRequest.  # noqa: E501


        :return: The device of this CameraRequest.  # noqa: E501
        :rtype: int
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this CameraRequest.


        :param device: The device of this CameraRequest.  # noqa: E501
        :type device: int
        """
        if self.local_vars_configuration.client_side_validation and device is None:  # noqa: E501
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    @property
    def name(self):
        """Gets the name of this CameraRequest.  # noqa: E501

        Descriptive name to identify this camera  # noqa: E501

        :return: The name of this CameraRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CameraRequest.

        Descriptive name to identify this camera  # noqa: E501

        :param name: The name of this CameraRequest.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def camera_type(self):
        """Gets the camera_type of this CameraRequest.  # noqa: E501


        :return: The camera_type of this CameraRequest.  # noqa: E501
        :rtype: CameraType
        """
        return self._camera_type

    @camera_type.setter
    def camera_type(self, camera_type):
        """Sets the camera_type of this CameraRequest.


        :param camera_type: The camera_type of this CameraRequest.  # noqa: E501
        :type camera_type: CameraType
        """

        self._camera_type = camera_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CameraRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CameraRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.paginated_gcode_file_list import PaginatedGcodeFileList  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPaginatedGcodeFileList(unittest.TestCase):
    """PaginatedGcodeFileList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedGcodeFileList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.paginated_gcode_file_list.PaginatedGcodeFileList()  # noqa: E501
        if include_optional :
            return PaginatedGcodeFileList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    printnanny_api_client.models.gcode_file.GcodeFile(
                        id = 56, 
                        user = 56, 
                        name = '', 
                        file = '', 
                        file_hash = '', 
                        octoprint_device = '', 
                        url = '', )
                    ]
            )
        else :
            return PaginatedGcodeFileList(
        )

    def testPaginatedGcodeFileList(self):
        """Test PaginatedGcodeFileList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.patched_octo_print_device_request import PatchedOctoPrintDeviceRequest  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPatchedOctoPrintDeviceRequest(unittest.TestCase):
    """PatchedOctoPrintDeviceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PatchedOctoPrintDeviceRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.patched_octo_print_device_request.PatchedOctoPrintDeviceRequest()  # noqa: E501
        if include_optional :
            return PatchedOctoPrintDeviceRequest(
                name = '0', 
                model = '0', 
                platform = '0', 
                cpu_flags = [
                    '0'
                    ], 
                hardware = '0', 
                revision = '0', 
                serial = '0', 
                cores = -2147483648, 
                ram = -2147483648, 
                python_version = '0', 
                pip_version = '0', 
                virtualenv = '0', 
                octoprint_version = '0', 
                plugin_version = '0', 
                print_nanny_client_version = '0', 
                print_nanny_beta_client_version = '0', 
                active_session = printnanny_api_client.models.print_session_request.PrintSessionRequest(
                    created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    octoprint_device = 56, 
                    active = True, 
                    session = '0', 
                    filepos = -2147483648, 
                    print_progress = -2147483648, 
                    time_elapsed = -2147483648, 
                    time_remaining = -2147483648, 
                    printer_profile = 56, 
                    gcode_file = 56, 
                    gcode_filename = '0', 
                    octoprint_job = {
                        'key' : null
                        }, 
                    print_job_status = null, )
            )
        else :
            return PatchedOctoPrintDeviceRequest(
        )

    def testPatchedOctoPrintDeviceRequest(self):
        """Test PatchedOctoPrintDeviceRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.print_nanny_plugin_event import PrintNannyPluginEvent  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPrintNannyPluginEvent(unittest.TestCase):
    """PrintNannyPluginEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintNannyPluginEvent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.print_nanny_plugin_event.PrintNannyPluginEvent()  # noqa: E501
        if include_optional :
            return PrintNannyPluginEvent(
                id = 56, 
                ts = 1.337, 
                event_source = None, 
                event_type = None, 
                octoprint_environment = printnanny_api_client.models.octoprint_environment.OctoprintEnvironment(
                    os = printnanny_api_client.models.octoprint_platform.OctoprintPlatform(
                        id = '', 
                        platform = '', 
                        bits = '', ), 
                    python = printnanny_api_client.models.octoprint_python.OctoprintPython(
                        version = '', 
                        pip = '', 
                        virtualenv = '', ), 
                    hardware = printnanny_api_client.models.octoprint_hardware.OctoprintHardware(
                        cores = 56, 
                        freq = 1.337, 
                        ram = 56, ), 
                    pi_support = printnanny_api_client.models.octoprint_pi_support.OctoprintPiSupport(
                        model = '', 
                        throttle_state = '', 
                        octopi_version = '', ), ), 
                octoprint_printer_data = printnanny_api_client.models.octoprint_printer_data.OctoprintPrinterData(
                    job = printnanny_api_client.models.octoprint_job.OctoprintJob(
                        file = null, 
                        estimated_print_time = 1.337, 
                        average_print_time = 1.337, 
                        last_print_time = 1.337, 
                        filament = {
                            'key' : null
                            }, ), 
                    state = printnanny_api_client.models.octoprint_printer_state.OctoprintPrinterState(
                        text = '', 
                        flags = printnanny_api_client.models.octoprint_printer_flags.OctoprintPrinterFlags(
                            operational = True, 
                            printing = True, 
                            cancelling = True, 
                            pausing = True, 
                            resuming = True, 
                            finishing = True, 
                            closed_or_error = True, 
                            error = True, 
                            paused = True, 
                            ready = True, 
                            sd_ready = True, ), ), 
                    user = '', 
                    current_z = 1.337, 
                    progress = printnanny_api_client.models.octoprint_progress.OctoprintProgress(
                        completion = 1.337, 
                        filepos = 56, 
                        print_time = 56, 
                        print_time_left = 56, 
                        print_time_origin = '', ), 
                    resends = {
                        'key' : null
                        }, 
                    offsets = {
                        'key' : null
                        }, ), 
                event_data = {
                    'key' : null
                    }, 
                temperature = {
                    'key' : null
                    }, 
                print_nanny_plugin_version = '', 
                print_nanny_client_version = '', 
                print_nanny_beta_client_version = '', 
                octoprint_version = '', 
                polymorphic_ctype = 56, 
                octoprint_device = 56, 
                user = 56, 
                print_session = 56
            )
        else :
            return PrintNannyPluginEvent(
                id = 56,
                octoprint_environment = printnanny_api_client.models.octoprint_environment.OctoprintEnvironment(
                    os = printnanny_api_client.models.octoprint_platform.OctoprintPlatform(
                        id = '', 
                        platform = '', 
                        bits = '', ), 
                    python = printnanny_api_client.models.octoprint_python.OctoprintPython(
                        version = '', 
                        pip = '', 
                        virtualenv = '', ), 
                    hardware = printnanny_api_client.models.octoprint_hardware.OctoprintHardware(
                        cores = 56, 
                        freq = 1.337, 
                        ram = 56, ), 
                    pi_support = printnanny_api_client.models.octoprint_pi_support.OctoprintPiSupport(
                        model = '', 
                        throttle_state = '', 
                        octopi_version = '', ), ),
                octoprint_printer_data = printnanny_api_client.models.octoprint_printer_data.OctoprintPrinterData(
                    job = printnanny_api_client.models.octoprint_job.OctoprintJob(
                        file = null, 
                        estimated_print_time = 1.337, 
                        average_print_time = 1.337, 
                        last_print_time = 1.337, 
                        filament = {
                            'key' : null
                            }, ), 
                    state = printnanny_api_client.models.octoprint_printer_state.OctoprintPrinterState(
                        text = '', 
                        flags = printnanny_api_client.models.octoprint_printer_flags.OctoprintPrinterFlags(
                            operational = True, 
                            printing = True, 
                            cancelling = True, 
                            pausing = True, 
                            resuming = True, 
                            finishing = True, 
                            closed_or_error = True, 
                            error = True, 
                            paused = True, 
                            ready = True, 
                            sd_ready = True, ), ), 
                    user = '', 
                    current_z = 1.337, 
                    progress = printnanny_api_client.models.octoprint_progress.OctoprintProgress(
                        completion = 1.337, 
                        filepos = 56, 
                        print_time = 56, 
                        print_time_left = 56, 
                        print_time_origin = '', ), 
                    resends = {
                        'key' : null
                        }, 
                    offsets = {
                        'key' : null
                        }, ),
                print_nanny_plugin_version = '',
                print_nanny_client_version = '',
                octoprint_version = '',
                polymorphic_ctype = 56,
                octoprint_device = 56,
                user = 56,
        )

    def testPrintNannyPluginEvent(self):
        """Test PrintNannyPluginEvent"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PrintNannyPluginEventRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ts': 'float',
        'event_source': 'AlphaEventSource',
        'event_type': 'OctoPrintNannyEvent',
        'octoprint_environment': 'OctoprintEnvironmentRequest',
        'octoprint_printer_data': 'OctoprintPrinterDataRequest',
        'event_data': 'dict(str, object)',
        'temperature': 'dict(str, object)',
        'print_nanny_plugin_version': 'str',
        'print_nanny_client_version': 'str',
        'print_nanny_beta_client_version': 'str',
        'octoprint_version': 'str',
        'octoprint_device': 'int',
        'print_session': 'int'
    }

    attribute_map = {
        'ts': 'ts',
        'event_source': 'event_source',
        'event_type': 'event_type',
        'octoprint_environment': 'octoprint_environment',
        'octoprint_printer_data': 'octoprint_printer_data',
        'event_data': 'event_data',
        'temperature': 'temperature',
        'print_nanny_plugin_version': 'print_nanny_plugin_version',
        'print_nanny_client_version': 'print_nanny_client_version',
        'print_nanny_beta_client_version': 'print_nanny_beta_client_version',
        'octoprint_version': 'octoprint_version',
        'octoprint_device': 'octoprint_device',
        'print_session': 'print_session'
    }

    def __init__(self, ts=None, event_source=None, event_type=None, octoprint_environment=None, octoprint_printer_data=None, event_data=None, temperature=None, print_nanny_plugin_version=None, print_nanny_client_version=None, print_nanny_beta_client_version=None, octoprint_version=None, octoprint_device=None, print_session=None, local_vars_configuration=None):  # noqa: E501
        """PrintNannyPluginEventRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._ts = None
        self._event_source = None
        self._event_type = None
        self._octoprint_environment = None
        self._octoprint_printer_data = None
        self._event_data = None
        self._temperature = None
        self._print_nanny_plugin_version = None
        self._print_nanny_client_version = None
        self._print_nanny_beta_client_version = None
        self._octoprint_version = None
        self._octoprint_device = None
        self._print_session = None
        self.discriminator = None

        if ts is not None:
            self.ts = ts
        self.event_source = event_source
        self.event_type = event_type
        self.octoprint_environment = octoprint_environment
        self.octoprint_printer_data = octoprint_printer_data
        self.event_data = event_data
        if temperature is not None:
            self.temperature = temperature
        self.print_nanny_plugin_version = print_nanny_plugin_version
        self.print_nanny_client_version = print_nanny_client_version
        self.print_nanny_beta_client_version = print_nanny_beta_client_version
        self.octoprint_version = octoprint_version
        self.octoprint_device = octoprint_device
        self.print_session = print_session

    @property
    def ts(self):
        """Gets the ts of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The ts of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: float
        """
        return self._ts

    @ts.setter
    def ts(self, ts):
        """Sets the ts of this PrintNannyPluginEventRequest.


        :param ts: The ts of this PrintNannyPluginEventRequest.  # noqa: E501
        :type ts: float
        """

        self._ts = ts

    @property
    def event_source(self):
        """Gets the event_source of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The event_source of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: AlphaEventSource
        """
        return self._event_source

    @event_source.setter
    def event_source(self, event_source):
        """Sets the event_source of this PrintNannyPluginEventRequest.


        :param event_source: The event_source of this PrintNannyPluginEventRequest.  # noqa: E501
        :type event_source: AlphaEventSource
        """

        self._event_source = event_source

    @property
    def event_type(self):
        """Gets the event_type of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The event_type of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: OctoPrintNannyEvent
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this PrintNannyPluginEventRequest.


        :param event_type: The event_type of this PrintNannyPluginEventRequest.  # noqa: E501
        :type event_type: OctoPrintNannyEvent
        """

        self._event_type = event_type

    @property
    def octoprint_environment(self):
        """Gets the octoprint_environment of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The octoprint_environment of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: OctoprintEnvironmentRequest
        """
        return self._octoprint_environment

    @octoprint_environment.setter
    def octoprint_environment(self, octoprint_environment):
        """Sets the octoprint_environment of this PrintNannyPluginEventRequest.


        :param octoprint_environment: The octoprint_environment of this PrintNannyPluginEventRequest.  # noqa: E501
        :type octoprint_environment: OctoprintEnvironmentRequest
        """
        if self.local_vars_configuration.client_side_validation and octoprint_environment is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_environment`, must not be `None`")  # noqa: E501

        self._octoprint_environment = octoprint_environment

    @property
    def octoprint_printer_data(self):
        """Gets the octoprint_printer_data of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The octoprint_printer_data of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: OctoprintPrinterDataRequest
        """
        return self._octoprint_printer_data

    @octoprint_printer_data.setter
    def octoprint_printer_data(self, octoprint_printer_data):
        """Sets the octoprint_printer_data of this PrintNannyPluginEventRequest.


        :param octoprint_printer_data: The octoprint_printer_data of this PrintNannyPluginEventRequest.  # noqa: E501
        :type octoprint_printer_data: OctoprintPrinterDataRequest
        """
        if self.local_vars_configuration.client_side_validation and octoprint_printer_data is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_printer_data`, must not be `None`")  # noqa: E501

        self._octoprint_printer_data = octoprint_printer_data

    @property
    def event_data(self):
        """Gets the event_data of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The event_data of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._event_data

    @event_data.setter
    def event_data(self, event_data):
        """Sets the event_data of this PrintNannyPluginEventRequest.


        :param event_data: The event_data of this PrintNannyPluginEventRequest.  # noqa: E501
        :type event_data: dict(str, object)
        """

        self._event_data = event_data

    @property
    def temperature(self):
        """Gets the temperature of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The temperature of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._temperature

    @temperature.setter
    def temperature(self, temperature):
        """Sets the temperature of this PrintNannyPluginEventRequest.


        :param temperature: The temperature of this PrintNannyPluginEventRequest.  # noqa: E501
        :type temperature: dict(str, object)
        """

        self._temperature = temperature

    @property
    def print_nanny_plugin_version(self):
        """Gets the print_nanny_plugin_version of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The print_nanny_plugin_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: str
        """
        return self._print_nanny_plugin_version

    @print_nanny_plugin_version.setter
    def print_nanny_plugin_version(self, print_nanny_plugin_version):
        """Sets the print_nanny_plugin_version of this PrintNannyPluginEventRequest.


        :param print_nanny_plugin_version: The print_nanny_plugin_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :type print_nanny_plugin_version: str
        """
        if self.local_vars_configuration.client_side_validation and print_nanny_plugin_version is None:  # noqa: E501
            raise ValueError("Invalid value for `print_nanny_plugin_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_plugin_version is not None and len(print_nanny_plugin_version) > 60):
            raise ValueError("Invalid value for `print_nanny_plugin_version`, length must be less than or equal to `60`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_plugin_version is not None and len(print_nanny_plugin_version) < 1):
            raise ValueError("Invalid value for `print_nanny_plugin_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._print_nanny_plugin_version = print_nanny_plugin_version

    @property
    def print_nanny_client_version(self):
        """Gets the print_nanny_client_version of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The print_nanny_client_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: str
        """
        return self._print_nanny_client_version

    @print_nanny_client_version.setter
    def print_nanny_client_version(self, print_nanny_client_version):
        """Sets the print_nanny_client_version of this PrintNannyPluginEventRequest.


        :param print_nanny_client_version: The print_nanny_client_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :type print_nanny_client_version: str
        """
        if self.local_vars_configuration.client_side_validation and print_nanny_client_version is None:  # noqa: E501
            raise ValueError("Invalid value for `print_nanny_client_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_client_version is not None and len(print_nanny_client_version) > 60):
            raise ValueError("Invalid value for `print_nanny_client_version`, length must be less than or equal to `60`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_client_version is not None and len(print_nanny_client_version) < 1):
            raise ValueError("Invalid value for `print_nanny_client_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._print_nanny_client_version = print_nanny_client_version

    @property
    def print_nanny_beta_client_version(self):
        """Gets the print_nanny_beta_client_version of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The print_nanny_beta_client_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: str
        """
        return self._print_nanny_beta_client_version

    @print_nanny_beta_client_version.setter
    def print_nanny_beta_client_version(self, print_nanny_beta_client_version):
        """Sets the print_nanny_beta_client_version of this PrintNannyPluginEventRequest.


        :param print_nanny_beta_client_version: The print_nanny_beta_client_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :type print_nanny_beta_client_version: str
        """
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_beta_client_version is not None and len(print_nanny_beta_client_version) > 60):
            raise ValueError("Invalid value for `print_nanny_beta_client_version`, length must be less than or equal to `60`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                print_nanny_beta_client_version is not None and len(print_nanny_beta_client_version) < 1):
            raise ValueError("Invalid value for `print_nanny_beta_client_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._print_nanny_beta_client_version = print_nanny_beta_client_version

    @property
    def octoprint_version(self):
        """Gets the octoprint_version of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The octoprint_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: str
        """
        return self._octoprint_version

    @octoprint_version.setter
    def octoprint_version(self, octoprint_version):
        """Sets the octoprint_version of this PrintNannyPluginEventRequest.


        :param octoprint_version: The octoprint_version of this PrintNannyPluginEventRequest.  # noqa: E501
        :type octoprint_version: str
        """
        if self.local_vars_configuration.client_side_validation and octoprint_version is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                octoprint_version is not None and len(octoprint_version) > 36):
            raise ValueError("Invalid value for `octoprint_version`, length must be less than or equal to `36`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                octoprint_version is not None and len(octoprint_version) < 1):
            raise ValueError("Invalid value for `octoprint_version`, length must be greater than or equal to `1`")  # noqa: E501

        self._octoprint_version = octoprint_version

    @property
    def octoprint_device(self):
        """Gets the octoprint_device of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The octoprint_device of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: int
        """
        return self._octoprint_device

    @octoprint_device.setter
    def octoprint_device(self, octoprint_device):
        """Sets the octoprint_device of this PrintNannyPluginEventRequest.


        :param octoprint_device: The octoprint_device of this PrintNannyPluginEventRequest.  # noqa: E501
        :type octoprint_device: int
        """
        if self.local_vars_configuration.client_side_validation and octoprint_device is None:  # noqa: E501
            raise ValueError("Invalid value for `octoprint_device`, must not be `None`")  # noqa: E501

        self._octoprint_device = octoprint_device

    @property
    def print_session(self):
        """Gets the print_session of this PrintNannyPluginEventRequest.  # noqa: E501


        :return: The print_session of this PrintNannyPluginEventRequest.  # noqa: E501
        :rtype: int
        """
        return self._print_session

    @print_session.setter
    def print_session(self, print_session):
        """Sets the print_session of this PrintNannyPluginEventRequest.


        :param print_session: The print_session of this PrintNannyPluginEventRequest.  # noqa: E501
        :type print_session: int
        """

        self._print_session = print_session

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrintNannyPluginEventRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrintNannyPluginEventRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.system_info_request import SystemInfoRequest  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestSystemInfoRequest(unittest.TestCase):
    """SystemInfoRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SystemInfoRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.system_info_request.SystemInfoRequest()  # noqa: E501
        if include_optional :
            return SystemInfoRequest(
                machine_id = '0', 
                hardware = '0', 
                revision = '0', 
                model = '0', 
                serial = '0', 
                cores = -2147483648, 
                ram = -9223372036854775808, 
                image_version = '0', 
                device = 56
            )
        else :
            return SystemInfoRequest(
                machine_id = '0',
                hardware = '0',
                revision = '0',
                model = '0',
                serial = '0',
                cores = -2147483648,
                ram = -9223372036854775808,
                image_version = '0',
                device = 56,
        )

    def testSystemInfoRequest(self):
        """Test SystemInfoRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.octoprint_printer_data import OctoprintPrinterData  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestOctoprintPrinterData(unittest.TestCase):
    """OctoprintPrinterData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OctoprintPrinterData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.octoprint_printer_data.OctoprintPrinterData()  # noqa: E501
        if include_optional :
            return OctoprintPrinterData(
                job = printnanny_api_client.models.octoprint_job.OctoprintJob(
                    file = null, 
                    estimated_print_time = 1.337, 
                    average_print_time = 1.337, 
                    last_print_time = 1.337, 
                    filament = {
                        'key' : null
                        }, ), 
                state = printnanny_api_client.models.octoprint_printer_state.OctoprintPrinterState(
                    text = '', 
                    flags = printnanny_api_client.models.octoprint_printer_flags.OctoprintPrinterFlags(
                        operational = True, 
                        printing = True, 
                        cancelling = True, 
                        pausing = True, 
                        resuming = True, 
                        finishing = True, 
                        closed_or_error = True, 
                        error = True, 
                        paused = True, 
                        ready = True, 
                        sd_ready = True, ), ), 
                user = '', 
                current_z = 1.337, 
                progress = printnanny_api_client.models.octoprint_progress.OctoprintProgress(
                    completion = 1.337, 
                    filepos = 56, 
                    print_time = 56, 
                    print_time_left = 56, 
                    print_time_origin = '', ), 
                resends = {
                    'key' : null
                    }, 
                offsets = {
                    'key' : null
                    }
            )
        else :
            return OctoprintPrinterData(
                job = printnanny_api_client.models.octoprint_job.OctoprintJob(
                    file = null, 
                    estimated_print_time = 1.337, 
                    average_print_time = 1.337, 
                    last_print_time = 1.337, 
                    filament = {
                        'key' : null
                        }, ),
                state = printnanny_api_client.models.octoprint_printer_state.OctoprintPrinterState(
                    text = '', 
                    flags = printnanny_api_client.models.octoprint_printer_flags.OctoprintPrinterFlags(
                        operational = True, 
                        printing = True, 
                        cancelling = True, 
                        pausing = True, 
                        resuming = True, 
                        finishing = True, 
                        closed_or_error = True, 
                        error = True, 
                        paused = True, 
                        ready = True, 
                        sd_ready = True, ), ),
                progress = printnanny_api_client.models.octoprint_progress.OctoprintProgress(
                    completion = 1.337, 
                    filepos = 56, 
                    print_time = 56, 
                    print_time_left = 56, 
                    print_time_origin = '', ),
                resends = {
                    'key' : null
                    },
                offsets = {
                    'key' : null
                    },
        )

    def testOctoprintPrinterData(self):
        """Test OctoprintPrinterData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.patched_printer_profile_request import PatchedPrinterProfileRequest  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPatchedPrinterProfileRequest(unittest.TestCase):
    """PatchedPrinterProfileRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PatchedPrinterProfileRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.patched_printer_profile_request.PatchedPrinterProfileRequest()  # noqa: E501
        if include_optional :
            return PatchedPrinterProfileRequest(
                octoprint_device = 56, 
                axes_e_inverted = True, 
                axes_e_speed = -2147483648, 
                axes_x_speed = -2147483648, 
                axes_x_inverted = True, 
                axes_y_inverted = True, 
                axes_y_speed = -2147483648, 
                axes_z_inverted = True, 
                axes_z_speed = -2147483648, 
                extruder_count = -2147483648, 
                extruder_nozzle_diameter = 1.337, 
                extruder_shared_nozzle = True, 
                heated_bed = True, 
                heated_chamber = True, 
                model = '', 
                name = '0', 
                octoprint_key = '0', 
                volume_custom_box = {
                    'key' : null
                    }, 
                volume_depth = 1.337, 
                volume_formfactor = '0', 
                volume_height = 1.337, 
                volume_origin = '0', 
                volume_width = 1.337
            )
        else :
            return PatchedPrinterProfileRequest(
        )

    def testPatchedPrinterProfileRequest(self):
        """Test PatchedPrinterProfileRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.octoprint_environment import OctoprintEnvironment  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestOctoprintEnvironment(unittest.TestCase):
    """OctoprintEnvironment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OctoprintEnvironment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.octoprint_environment.OctoprintEnvironment()  # noqa: E501
        if include_optional :
            return OctoprintEnvironment(
                os = printnanny_api_client.models.octoprint_platform.OctoprintPlatform(
                    id = '', 
                    platform = '', 
                    bits = '', ), 
                python = printnanny_api_client.models.octoprint_python.OctoprintPython(
                    version = '', 
                    pip = '', 
                    virtualenv = '', ), 
                hardware = printnanny_api_client.models.octoprint_hardware.OctoprintHardware(
                    cores = 56, 
                    freq = 1.337, 
                    ram = 56, ), 
                pi_support = printnanny_api_client.models.octoprint_pi_support.OctoprintPiSupport(
                    model = '', 
                    throttle_state = '', 
                    octopi_version = '', )
            )
        else :
            return OctoprintEnvironment(
                os = printnanny_api_client.models.octoprint_platform.OctoprintPlatform(
                    id = '', 
                    platform = '', 
                    bits = '', ),
                python = printnanny_api_client.models.octoprint_python.OctoprintPython(
                    version = '', 
                    pip = '', 
                    virtualenv = '', ),
                hardware = printnanny_api_client.models.octoprint_hardware.OctoprintHardware(
                    cores = 56, 
                    freq = 1.337, 
                    ram = 56, ),
                pi_support = printnanny_api_client.models.octoprint_pi_support.OctoprintPiSupport(
                    model = '', 
                    throttle_state = '', 
                    octopi_version = '', ),
        )

    def testOctoprintEnvironment(self):
        """Test OctoprintEnvironment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class CloudiotDevice(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'num_id': 'int',
        'task_topic': 'str',
        'config_topic': 'str',
        'state_topic': 'str',
        'gcp_project_id': 'str',
        'gcp_region': 'str',
        'gcp_cloudiot_device_registry': 'str',
        'mqtt_bridge_hostname': 'str',
        'mqtt_bridge_port': 'int',
        'mqtt_client_id': 'str',
        'name': 'str',
        'id': 'str',
        'device': 'int'
    }

    attribute_map = {
        'num_id': 'num_id',
        'task_topic': 'task_topic',
        'config_topic': 'config_topic',
        'state_topic': 'state_topic',
        'gcp_project_id': 'gcp_project_id',
        'gcp_region': 'gcp_region',
        'gcp_cloudiot_device_registry': 'gcp_cloudiot_device_registry',
        'mqtt_bridge_hostname': 'mqtt_bridge_hostname',
        'mqtt_bridge_port': 'mqtt_bridge_port',
        'mqtt_client_id': 'mqtt_client_id',
        'name': 'name',
        'id': 'id',
        'device': 'device'
    }

    def __init__(self, num_id=None, task_topic=None, config_topic=None, state_topic=None, gcp_project_id=None, gcp_region=None, gcp_cloudiot_device_registry=None, mqtt_bridge_hostname=None, mqtt_bridge_port=None, mqtt_client_id=None, name=None, id=None, device=None, local_vars_configuration=None):  # noqa: E501
        """CloudiotDevice - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._num_id = None
        self._task_topic = None
        self._config_topic = None
        self._state_topic = None
        self._gcp_project_id = None
        self._gcp_region = None
        self._gcp_cloudiot_device_registry = None
        self._mqtt_bridge_hostname = None
        self._mqtt_bridge_port = None
        self._mqtt_client_id = None
        self._name = None
        self._id = None
        self._device = None
        self.discriminator = None

        self.num_id = num_id
        self.task_topic = task_topic
        self.config_topic = config_topic
        self.state_topic = state_topic
        self.gcp_project_id = gcp_project_id
        self.gcp_region = gcp_region
        self.gcp_cloudiot_device_registry = gcp_cloudiot_device_registry
        self.mqtt_bridge_hostname = mqtt_bridge_hostname
        self.mqtt_bridge_port = mqtt_bridge_port
        self.mqtt_client_id = mqtt_client_id
        self.name = name
        self.id = id
        self.device = device

    @property
    def num_id(self):
        """Gets the num_id of this CloudiotDevice.  # noqa: E501


        :return: The num_id of this CloudiotDevice.  # noqa: E501
        :rtype: int
        """
        return self._num_id

    @num_id.setter
    def num_id(self, num_id):
        """Sets the num_id of this CloudiotDevice.


        :param num_id: The num_id of this CloudiotDevice.  # noqa: E501
        :type num_id: int
        """
        if self.local_vars_configuration.client_side_validation and num_id is None:  # noqa: E501
            raise ValueError("Invalid value for `num_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                num_id is not None and num_id > 9223372036854775807):  # noqa: E501
            raise ValueError("Invalid value for `num_id`, must be a value less than or equal to `9223372036854775807`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                num_id is not None and num_id < -9223372036854775808):  # noqa: E501
            raise ValueError("Invalid value for `num_id`, must be a value greater than or equal to `-9223372036854775808`")  # noqa: E501

        self._num_id = num_id

    @property
    def task_topic(self):
        """Gets the task_topic of this CloudiotDevice.  # noqa: E501


        :return: The task_topic of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._task_topic

    @task_topic.setter
    def task_topic(self, task_topic):
        """Sets the task_topic of this CloudiotDevice.


        :param task_topic: The task_topic of this CloudiotDevice.  # noqa: E501
        :type task_topic: str
        """
        if self.local_vars_configuration.client_side_validation and task_topic is None:  # noqa: E501
            raise ValueError("Invalid value for `task_topic`, must not be `None`")  # noqa: E501

        self._task_topic = task_topic

    @property
    def config_topic(self):
        """Gets the config_topic of this CloudiotDevice.  # noqa: E501


        :return: The config_topic of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._config_topic

    @config_topic.setter
    def config_topic(self, config_topic):
        """Sets the config_topic of this CloudiotDevice.


        :param config_topic: The config_topic of this CloudiotDevice.  # noqa: E501
        :type config_topic: str
        """
        if self.local_vars_configuration.client_side_validation and config_topic is None:  # noqa: E501
            raise ValueError("Invalid value for `config_topic`, must not be `None`")  # noqa: E501

        self._config_topic = config_topic

    @property
    def state_topic(self):
        """Gets the state_topic of this CloudiotDevice.  # noqa: E501


        :return: The state_topic of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._state_topic

    @state_topic.setter
    def state_topic(self, state_topic):
        """Sets the state_topic of this CloudiotDevice.


        :param state_topic: The state_topic of this CloudiotDevice.  # noqa: E501
        :type state_topic: str
        """
        if self.local_vars_configuration.client_side_validation and state_topic is None:  # noqa: E501
            raise ValueError("Invalid value for `state_topic`, must not be `None`")  # noqa: E501

        self._state_topic = state_topic

    @property
    def gcp_project_id(self):
        """Gets the gcp_project_id of this CloudiotDevice.  # noqa: E501


        :return: The gcp_project_id of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._gcp_project_id

    @gcp_project_id.setter
    def gcp_project_id(self, gcp_project_id):
        """Sets the gcp_project_id of this CloudiotDevice.


        :param gcp_project_id: The gcp_project_id of this CloudiotDevice.  # noqa: E501
        :type gcp_project_id: str
        """
        if self.local_vars_configuration.client_side_validation and gcp_project_id is None:  # noqa: E501
            raise ValueError("Invalid value for `gcp_project_id`, must not be `None`")  # noqa: E501

        self._gcp_project_id = gcp_project_id

    @property
    def gcp_region(self):
        """Gets the gcp_region of this CloudiotDevice.  # noqa: E501


        :return: The gcp_region of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._gcp_region

    @gcp_region.setter
    def gcp_region(self, gcp_region):
        """Sets the gcp_region of this CloudiotDevice.


        :param gcp_region: The gcp_region of this CloudiotDevice.  # noqa: E501
        :type gcp_region: str
        """
        if self.local_vars_configuration.client_side_validation and gcp_region is None:  # noqa: E501
            raise ValueError("Invalid value for `gcp_region`, must not be `None`")  # noqa: E501

        self._gcp_region = gcp_region

    @property
    def gcp_cloudiot_device_registry(self):
        """Gets the gcp_cloudiot_device_registry of this CloudiotDevice.  # noqa: E501


        :return: The gcp_cloudiot_device_registry of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._gcp_cloudiot_device_registry

    @gcp_cloudiot_device_registry.setter
    def gcp_cloudiot_device_registry(self, gcp_cloudiot_device_registry):
        """Sets the gcp_cloudiot_device_registry of this CloudiotDevice.


        :param gcp_cloudiot_device_registry: The gcp_cloudiot_device_registry of this CloudiotDevice.  # noqa: E501
        :type gcp_cloudiot_device_registry: str
        """
        if self.local_vars_configuration.client_side_validation and gcp_cloudiot_device_registry is None:  # noqa: E501
            raise ValueError("Invalid value for `gcp_cloudiot_device_registry`, must not be `None`")  # noqa: E501

        self._gcp_cloudiot_device_registry = gcp_cloudiot_device_registry

    @property
    def mqtt_bridge_hostname(self):
        """Gets the mqtt_bridge_hostname of this CloudiotDevice.  # noqa: E501


        :return: The mqtt_bridge_hostname of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_bridge_hostname

    @mqtt_bridge_hostname.setter
    def mqtt_bridge_hostname(self, mqtt_bridge_hostname):
        """Sets the mqtt_bridge_hostname of this CloudiotDevice.


        :param mqtt_bridge_hostname: The mqtt_bridge_hostname of this CloudiotDevice.  # noqa: E501
        :type mqtt_bridge_hostname: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_bridge_hostname is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_bridge_hostname`, must not be `None`")  # noqa: E501

        self._mqtt_bridge_hostname = mqtt_bridge_hostname

    @property
    def mqtt_bridge_port(self):
        """Gets the mqtt_bridge_port of this CloudiotDevice.  # noqa: E501


        :return: The mqtt_bridge_port of this CloudiotDevice.  # noqa: E501
        :rtype: int
        """
        return self._mqtt_bridge_port

    @mqtt_bridge_port.setter
    def mqtt_bridge_port(self, mqtt_bridge_port):
        """Sets the mqtt_bridge_port of this CloudiotDevice.


        :param mqtt_bridge_port: The mqtt_bridge_port of this CloudiotDevice.  # noqa: E501
        :type mqtt_bridge_port: int
        """
        if self.local_vars_configuration.client_side_validation and mqtt_bridge_port is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_bridge_port`, must not be `None`")  # noqa: E501

        self._mqtt_bridge_port = mqtt_bridge_port

    @property
    def mqtt_client_id(self):
        """Gets the mqtt_client_id of this CloudiotDevice.  # noqa: E501


        :return: The mqtt_client_id of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._mqtt_client_id

    @mqtt_client_id.setter
    def mqtt_client_id(self, mqtt_client_id):
        """Sets the mqtt_client_id of this CloudiotDevice.


        :param mqtt_client_id: The mqtt_client_id of this CloudiotDevice.  # noqa: E501
        :type mqtt_client_id: str
        """
        if self.local_vars_configuration.client_side_validation and mqtt_client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `mqtt_client_id`, must not be `None`")  # noqa: E501

        self._mqtt_client_id = mqtt_client_id

    @property
    def name(self):
        """Gets the name of this CloudiotDevice.  # noqa: E501


        :return: The name of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CloudiotDevice.


        :param name: The name of this CloudiotDevice.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this CloudiotDevice.  # noqa: E501


        :return: The id of this CloudiotDevice.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CloudiotDevice.


        :param id: The id of this CloudiotDevice.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                id is not None and len(id) > 255):
            raise ValueError("Invalid value for `id`, length must be less than or equal to `255`")  # noqa: E501

        self._id = id

    @property
    def device(self):
        """Gets the device of this CloudiotDevice.  # noqa: E501


        :return: The device of this CloudiotDevice.  # noqa: E501
        :rtype: int
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this CloudiotDevice.


        :param device: The device of this CloudiotDevice.  # noqa: E501
        :type device: int
        """
        if self.local_vars_configuration.client_side_validation and device is None:  # noqa: E501
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CloudiotDevice):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CloudiotDevice):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.paginated_remote_command_event_list import PaginatedRemoteCommandEventList  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestPaginatedRemoteCommandEventList(unittest.TestCase):
    """PaginatedRemoteCommandEventList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaginatedRemoteCommandEventList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.paginated_remote_command_event_list.PaginatedRemoteCommandEventList()  # noqa: E501
        if include_optional :
            return PaginatedRemoteCommandEventList(
                count = 123, 
                next = 'http://api.example.org/accounts/?page=4', 
                previous = 'http://api.example.org/accounts/?page=2', 
                results = [
                    printnanny_api_client.models.remote_command_event.RemoteCommandEvent(
                        id = 56, 
                        ts = 1.337, 
                        event_source = null, 
                        event_type = null, 
                        octoprint_environment = printnanny_api_client.models.octoprint_environment.OctoprintEnvironment(
                            os = printnanny_api_client.models.octoprint_platform.OctoprintPlatform(
                                id = '', 
                                platform = '', 
                                bits = '', ), 
                            python = printnanny_api_client.models.octoprint_python.OctoprintPython(
                                version = '', 
                                pip = '', 
                                virtualenv = '', ), 
                            hardware = printnanny_api_client.models.octoprint_hardware.OctoprintHardware(
                                cores = 56, 
                                freq = 1.337, 
                                ram = 56, ), 
                            pi_support = printnanny_api_client.models.octoprint_pi_support.OctoprintPiSupport(
                                model = '', 
                                throttle_state = '', 
                                octopi_version = '', ), ), 
                        octoprint_printer_data = printnanny_api_client.models.octoprint_printer_data.OctoprintPrinterData(
                            job = printnanny_api_client.models.octoprint_job.OctoprintJob(
                                file = null, 
                                estimated_print_time = 1.337, 
                                average_print_time = 1.337, 
                                last_print_time = 1.337, 
                                filament = {
                                    'key' : null
                                    }, ), 
                            state = printnanny_api_client.models.octoprint_printer_state.OctoprintPrinterState(
                                text = '', 
                                flags = printnanny_api_client.models.octoprint_printer_flags.OctoprintPrinterFlags(
                                    operational = True, 
                                    printing = True, 
                                    cancelling = True, 
                                    pausing = True, 
                                    resuming = True, 
                                    finishing = True, 
                                    closed_or_error = True, 
                                    error = True, 
                                    paused = True, 
                                    ready = True, 
                                    sd_ready = True, ), ), 
                            user = '', 
                            current_z = 1.337, 
                            progress = printnanny_api_client.models.octoprint_progress.OctoprintProgress(
                                completion = 1.337, 
                                filepos = 56, 
                                print_time = 56, 
                                print_time_left = 56, 
                                print_time_origin = '', ), 
                            resends = {
                                'key' : null
                                }, 
                            offsets = {
                                'key' : null
                                }, ), 
                        event_data = {
                            'key' : null
                            }, 
                        temperature = {
                            'key' : null
                            }, 
                        print_nanny_plugin_version = '', 
                        print_nanny_client_version = '', 
                        print_nanny_beta_client_version = '', 
                        octoprint_version = '', 
                        polymorphic_ctype = 56, 
                        octoprint_device = 56, 
                        user = 56, 
                        print_session = 56, )
                    ]
            )
        else :
            return PaginatedRemoteCommandEventList(
        )

    def testPaginatedRemoteCommandEventList(self):
        """Test PaginatedRemoteCommandEventList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
